<?php
/**
 * 简单商品价格计算类(注解版)
 * price::price_uid(商品ID); 获取商品价格用
 * price::price_uid(商品ID,用户ID); 获取商品价格用(自定义用户ID)
 * price::reckon(-2,商品ID,1); 获取商品详细套餐价格用,返回数组
 */

/**
 * Class price
 */

class price {
    public $gid;
    public $uid;
    /**
     * @param $gid 商品ID
     * @param $uid 若未自定义,则自动获取
     * @return array|int
     * 根据商品ID取出需要的价格！
     */
    public function price_uid($gid,$uid=null){
        if($uid<>null){
            return price::price_conversion($uid,$gid);
        }else{
            if (reward::user_landing() == 1){
                $USERDATA = login_data::login_verify();
                return price::price_conversion($USERDATA['id'],$gid);
            }else{
                $price_arr = price::reckon(-1,$gid);
                $price_arr['level'] = '游客价格';
                return $price_arr;
            }
        }
    }
    /**
     * @param $uid
     * @param $gid
     * @return array|int
     * 密价商品输出简化
     */
    public function price_conversion($uid,$gid){
        $price_arr = price::reckon($uid,$gid);
        if($price_arr['state']==-1){
            $level = '此商品无密价';
        }else{
            $level = $price_arr['name'];
            if($level==''){
                $level = '最高密价';
            }
        }
        $price_arr['level'] = $level;
        return $price_arr;
    }
    /**
     * @param $uid 用户ID,若用户ID为-2则是站长后台，若为-1或0+ 则是用户或游客！
     * @param $gid 商品ID
     * @param null $list 验证是否是站长后台数据
     * @return array|int 输出商品价格数组
     * 需获取商品售价,若未设置商品价格，则自动x1.25倍！
     */
    public function reckon($uid=-2,$gid,$list=null){
        global $DB;
        $gid = (int)$gid;
        $re = $DB->get_row("SELECT method,money,price,points FROM `sky_goods` WHERE gid = $gid LIMIT 1");
        if(!$re)return ['price'=>0,'points'=>0];

        /**
         * 查看此商品是否设置了密价等级
         */

        if (in_array(8, json_decode($re['method'], TRUE))) {

            $mis_arr = [];
            $rmi = $DB->query("SELECT name,priceis,pointsis FROM `sky_price` ORDER BY `sort` ");
            while ($rt = $DB->fetch($rmi)){
                $mis_arr[] = $rt;
            }
            /**
             * 若是开启了密价，则采用等级规则
             */

            if($list<>null) #若是后台价格列表
            {
                /**
                 * 计算出所有等级价格列表！
                 */
                $arr = [];
                foreach ($mis_arr as $rt){
                    $arr[] = price::price_grade($re,$rt);
                }

                return [
                    'state'=>1,
                    'array'=>$arr
                ];
            }else{
                /**
                 * 用户购买时所看到的价格！
                 */
                if($uid==-1){
                    /**
                     * 游客展示V1密价
                     */
                    return price::price_v1($re,$mis_arr);
                }else{
                    /**
                     * 已经登陆用户则展示自己等级匹配的点数
                     * 条件，正常状态用户
                     */
                    $mid = $DB->get_row("SELECT grade FROM `sky_user` WHERE id = $uid AND state = 1  LIMIT 1");
                    if(!$mid)return price::default_price($re);
                    $mul = $mis_arr[($mid['grade']-1)];
                    return $arr = price::price_grade($re,$mul);
                }
            }
        }else{
            /**
             * 未开启商品显示自定义价格,若自定义价格为空,则显示 成本价*1.25;
             */
            return price::default_price($re);
        }
    }

    /**
     * @param $goods 商品信息
     * @param $mis_arr 密价规则
     * 游客默认显示V1密价
     */
    public function price_v1($goods,$mis_arr){
        if(count($mis_arr)==0){ //无规则显示默认！
            return price::default_price($goods);
        }else{ //直接显示最低价密价V1
            $mul = $mis_arr[0];
            return $arr = price::price_grade($goods,$mul);
        }
    }

    /**
     * @param $re 商品数据
     * @return array
     * 商品原价计算方法
     * 若未开启商品等级价格，则显示商品原价！
     */
    public function default_price($re){
        if($re['price']==''||$re['price']==null){
            $price = ($re['money']-0) * 1.5; //若未填写商品价格,默认成本价的1.5倍
        }else{
            $price = $re['price'];
        }

        if($re['points']==''||$re['points']==null){
            $points = $re['points'] * 1500; //若未填写商品价格,默认1000倍兑换数
        }else{
            $points = $re['points'];
        }

        /**
         * 保本操作
         */

        if($price<$re['money']){
            $price = $re['money'] * 1.15; //价格倍数,默认1.15倍,保本无需太高
        }

        if($points<$re['money']){
            $points = $re['money'] * 1000;
        }

        return [
            'state'=>-1,
            'points'=>round($points,0),
            'price'=>(float)$price,
        ];
    }

    /**
     * @param $re 商品数据
     * @param $rt 等级规则
     * @return array 返回根据此规则计算的价格
     * 等级价格计算方法
     */
    public function price_grade($re,$rt){

        if($re['money']==0){ //免费商品
            $points = 0;
            $price = 0;
        }else{
            $price = 0; #初始化售价
            $points = 0; #初始化兑换点

            $arr_price = explode('|',$rt['priceis']);
            foreach ($arr_price as $v){
                $u = explode(',',$v);
                if($re['money'] >= $u[0]){
                    $price = $re['money'] * ($u[1]+0);
                }
            }

            $arr_points = explode('|',$rt['pointsis']);
            foreach ($arr_points as $v){
                $u = explode(',',$v);
                if($re['money'] >= $u[0]){
                    $points = $re['money'] * ($u[1]+0);
                }
            }

            if($price<$re['money']){
                $price = $re['money'] * 1.15;
            }

            if($points<$re['money']){
                $points = $re['money'] * 1000;
            }
        }

         return [
            'name'=>$rt['name'],
            'points'=>round($points,0),
            'price'=>(float)$price
        ];
    }
}